.. highlight:: shell

============
Installation
============

..
   Stable release
   --------------

   To install ratschlab common, run this command in your terminal:

   .. code-block:: console

       $ pip install ratschlab_common

   This is the preferred method to install ratschlab common, as it will always install the most recent stable release.

   If you don't have `pip`_ installed, this `Python installation guide`_ can guide
   you through the process.

   .. _pip: https://pip.pypa.io
   .. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for ratschlab common can be downloaded from the `Github repo`_.

You can clone the repository:

.. code-block:: console

    $ git clone git://github.com/ratschlab/ratschlab_common

..
   Or download the `tarball`_:

   .. code-block:: console

       $ curl  -OL https://github.com/ratschlab/ratschlab_common/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/ratschlab/ratschlab_common
..

   .. _tarball: https://github.com/ratschlab/ratschlab_common/tarball/master
